package
Version:
v0.0.0-...-ce52065
Opens a new window with list of versions in this module.
Published: Dec 16, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Node struct {
Profiles []map[string]interface{} `json:"data,omitempty"`
Meta map[string]interface{} `json:"meta,omitempty"`
Errors map[string]interface{} `json:"errors,omitempty"`
}
type Req struct {
SearchAfter interface{} `json:"search_after"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.